@@ -2,7 +2,7 @@ from kraken.futures.market.market import MarketClient
 from kraken.futures.trade.trade import TradeClient
 from kraken.futures.user.user import UserClient
 from kraken.futures.funding.funding import FundingClient
-from kraken.futures.ws_client.ws_client import FuturesWsClientCl
+from kraken.futures.websocket.websocket import KrakenFuturesWSClientCl
 
 class User(UserClient):
     pass
@@ -16,5 +16,5 @@ class Market(MarketClient):
 class Funding(FundingClient):
     pass
 
-class WsClient(FuturesWsClientCl):
+class KrakenFuturesWSClient(KrakenFuturesWSClientCl):
     pass
\ No newline at end of file
